<%-- $Id: edit_extravaluetype.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006, 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Type"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ExtraValueType"
	import="net.sf.basedb.core.Formula"
	import="net.sf.basedb.core.Coloring"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.EXTRAVALUETYPE;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Edit "+itemType);
try
{
	String title = null;
	ExtraValueType extraValueType = null;
	Coloring coloring = null;
	Formula.AverageMethod currentAverageMethod = null;

	if (itemId == 0)
	{
		title = "Create extra value type";
		cc.removeObject("item");
		currentAverageMethod = Formula.AverageMethod.fromValue(Values.getInt(cc.getPropertyValue("averageMethod"),
			Formula.AverageMethod.ARITHMETIC_MEAN.getValue()));
		coloring = new Coloring();
		coloring.setUsingColors(Values.getBoolean(cc.getPropertyValue("coloring.usingColors")));
		coloring.setLogarithmic(Values.getBoolean(cc.getPropertyValue("coloring.logarithmic")));
		coloring.setMinValue(Values.getFloat(cc.getPropertyValue("coloring.minValue"), null));
		coloring.setMidValue(Values.getFloat(cc.getPropertyValue("coloring.midValue"), null));
		coloring.setMaxValue(Values.getFloat(cc.getPropertyValue("coloring.maxValue"), null));
	}
	else
	{
		extraValueType = ExtraValueType.getById(dc, itemId);
		extraValueType.checkPermission(Permission.WRITE);
		currentAverageMethod = extraValueType.getAverageMethod();
		coloring = extraValueType.getColoring();
		cc.setObject("item", extraValueType);
		title = "Edit extra value type -- " + HTML.encodeTags(extraValueType.getName());
	}
	
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), extraValueType);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~extravaluetypes.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings" /></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="extraValueType">
		<input type="hidden" name="cmd" value="UpdateItem">

		<t:tabcontrol id="settings" 
			subclass="content dialogtabcontrol"
			position="bottom" remember="<%=extraValueType != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Extra value type" 
			helpid="extravaluetype.edit">
			<table class="fullform input100 smaller">
			<tr>
				<th>Name</th>
				<td><input class="text required auto-init" type="text" name="name" data-auto-init="<%=extraValueType == null ? "focus-select" : "focus" %>"
					value="<%=HTML.encodeTags(extraValueType == null ? Values.getString(cc.getPropertyValue("name"), "New extra value type") : extraValueType.getName())%>" 
					maxlength="<%=ExtraValueType.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>External ID</th>
				<td><input class="text required" type="text" name="external_id" 
					value="<%=HTML.encodeTags(extraValueType == null ? Values.getString(cc.getPropertyValue("externalId")) : extraValueType.getExternalId())%>" 
					maxlength="<%=ExtraValueType.MAX_EXTERNAL_ID_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>Value type</th>
				<td>
					<%
					if (extraValueType != null)
					{
						%>
						<%=extraValueType.getValueType()%>
						<%
					}
					else
					{
						int currentValueType = Values.getInt(cc.getPropertyValue("valueType"));
						%>
						<select name="value_type" class="required unchangeable selectionlist" id="value_type">
						<option value="<%=Type.INT.name()%>" 
							<%=Type.INT.getValue() == currentValueType ? "selected" : "" %>><%=Type.INT%>
						<option value="<%=Type.FLOAT.name()%>"
							<%=Type.FLOAT.getValue() == currentValueType ? "selected" : "" %>><%=Type.FLOAT%>
						<option value="<%=Type.STRING.name()%>"
							<%=Type.STRING.getValue() == currentValueType ? "selected" : "" %>><%=Type.STRING%>
						</select>
						<%
					}
					%>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Avg. method</th>
				<td>
					<select name="averageMethod" class="required selectionlist">
					<%
					for (Formula.AverageMethod method : Formula.AverageMethod.values())
					{
						String selected = method == currentAverageMethod ? "selected" : "";
						%>
						<option value="<%=method.name()%>" <%=selected%>><%=HTML.encodeTags(method.toString())%>
						<%
					}
					%>
					</select>
				</td>
				<td></td>
			</tr>
			<%
			if (extraValueType == null || extraValueType.getValueType().isNumerical())
			{
				%>
				<tr>
					<th><label for="use_colors">Use colors</label></th>
					<td>
						<input type="checkbox" name="use_colors" value="1" id="use_colors"
							<%=coloring.isUsingColors() ? "checked" : "" %>>
					</td>
					<td></td>
				</tr>
				<tr>
					<th class="subprompt">Min value</th>
					<td>
						<input type="text" class="text" name="min_value" id="min_value"
							 value="<%=Values.formatNumber(coloring.getMinValue(), -1)%>"
							 maxlength="6"  style="width: 6em;">
						Mid value
						<input type="text" class="text" name="mid_value" id="mid_value"
							 value="<%=Values.formatNumber(coloring.getMidValue(), -1)%>"
							 maxlength="6"  style="width: 6em;">
						Max value
						<input type="text" class="text" name="max_value" id="max_value"
							 value="<%=Values.formatNumber(coloring.getMaxValue(), -1)%>"
							 maxlength="6" style="width: 6em;">
					</td>
					<td></td>
				</tr>
				<tr>
					<th class="subprompt"><label for="logarithmic">Logarithmic</label></th>
					<td>
						<input type="checkbox" name="logarithmic" value="1" id="logarithmic"
							<%=coloring.isLogarithmic() ? "checked" : "" %>>
					</td>
					<td></td>
				</tr>
				<%
			}
			%>
			<tr class="dynamic">
				<th>Description</th>
				<td>
					<textarea class="text" rows="6" name="description" id="description"
						><%=HTML.encodeTags(extraValueType == null ? cc.getPropertyValue("description") : extraValueType.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>
		
		<div class="legend">
			<base:icon image="required.png" />= required information
			<%if (extraValueType == null) {%><br>
				<base:icon image="unchangeable.png" />= can't be changed later
			<%}%>
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
