<%-- $Id: select_plugin.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.PluginConfiguration"
	import="net.sf.basedb.core.PluginType"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.Job"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.core.query.Expressions"
	import="net.sf.basedb.core.query.Restrictions"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.core.plugin.InteractivePlugin"
	import="net.sf.basedb.core.plugin.AutoDetectingImporter"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.ContextUtil"
	import="net.sf.basedb.util.ContextUtil.ContextResult"
	import="net.sf.basedb.clients.web.util.HTML"
	import="java.util.Set"
	import="java.util.Map"
	import="java.util.List"
	import="org.json.simple.JSONObject"
	import="org.json.simple.JSONArray"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>

<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final Item itemType = Item.valueOf(request.getParameter("item_type"));
final String subContext = Values.getString(request.getParameter("subcontext"), "");
final GuiContext.Type contextType = GuiContext.Type.valueOf(request.getParameter("context_type"));
final Plugin.MainType mainType = Plugin.MainType.valueOf(request.getParameter("main_type"));
final GuiContext context = new GuiContext(itemType, contextType);
final String title = request.getParameter("title");
final String message = request.getParameter("message");
final DbControl dc = sc.newDbControl(":Select plug-in");
final float scale = Base.getScale(sc);
final boolean anotherIsOpen = sc.getSessionSetting("plugin.configure.plugin") != null;

try
{
	List<ContextResult> contextResults = sc.getSessionSetting("PLUGINS");
	Set<String> messages = sc.getSessionSetting("MESSAGES");
	StringBuilder descriptions = new StringBuilder();
	
	JSONArray jsonPlugins = new JSONArray();
	PluginDefinition lastPlugin = null;
	JSONObject jsonPlugin = null;
	JSONArray jsonConfigurations = null;
	for (ContextResult result : contextResults)
	{
		if (result.isInContext())
		{
			PluginDefinition pd = result.getPluginDefinition();
			if (!pd.equals(lastPlugin))
			{
				lastPlugin = pd;
				dc.reattachItem(pd, false);
				
				jsonPlugin = new JSONObject();
				jsonConfigurations = new JSONArray();
				jsonPlugin.put("id", pd.getId());
				jsonPlugin.put("name", pd.getName());
				jsonPlugin.put("description", HTML.niceFormat("<b>" + pd.getName() + "</b>\n" + pd.getDescription()));
				jsonPlugin.put("autoDetect", false);
				jsonPlugin.put("supportsConfig", pd.supportsConfigurations());
				jsonPlugin.put("requiresConfig", pd.requiresConfiguration());
				jsonPlugin.put("configurations", jsonConfigurations);
				jsonPlugins.add(jsonPlugin);
			}
			PluginConfiguration pc = result.getPluginConfiguration();
			if (pc != null)
			{
				JSONObject jsonConfig = new JSONObject();
				jsonConfig.put("id", pc.getId());
				jsonConfig.put("name", pc.getName());
				jsonConfig.put("description", HTML.niceFormat("<b>" + pc.getName() + "</b>\n" +pc.getDescription()));
				jsonConfigurations.add(jsonConfig);
			}
		}
	}
	%>
	<base:page type="popup" title="<%=title%>">
	<base:head scripts="~select_plugin.js" />
	<base:body>
		<h1><%=title%> <base:help helpid="runplugin.selectplugin" /></h1>
		<div id="page-data" class="datacontainer" 
			data-plugins="<%=HTML.encodeTags(jsonPlugins.toJSONString())%>"
			data-another-wizard="<%=anotherIsOpen ? 1 : 0%>"></div>
		<form name="plugin" action="index.jsp" method="post">
		<input type="hidden" name="ID" value="<%=ID%>">
		<input type="hidden" name="cmd" value="NewJob">
		<input type="hidden" name="item_type" value="<%=itemType.name()%>">
		<input type="hidden" name="subcontext" value="<%=subContext%>">
		<input type="hidden" name="context_type" value="<%=contextType.name()%>">
		<input type="hidden" name="main_type" value="<%=mainType.name()%>">
		<input type="hidden" name="title" value="<%=title%>">
		<input type="hidden" name="warnIfOpen" value="1">
		<input type="hidden" name="plugindefinition_id" value="">
		<input type="hidden" name="pluginconfiguration_id" value="">

		<div class="content bottomborder">
		
			<div class="absolutefull bg-filled-100" style="height: 4.5em;">
				<table style="height: 100%; margin:auto;"><tr><td>
						<%
						if (anotherIsOpen)
						{
							%>
							<div class="messagecontainer error">
								Another plug-in configuration wizard is open, or it hasn't properly 
								clean up after itself.
								If you continue unsaved settings in the other wizard is lost.
							</div>
							<%
						}
						else
						{
							%>
							<%
							if (message != null)
							{
								%>
								<%=message%>
								<%
							}
							else
							{
								%>
								Please select the plugin and, optionally, the configuration to use.
								<%
							}
							%>
							<%
						}
						%>
				</td></tr></table>
			</div>
		
			<div class="absolutefull topborder" style="top: 4.5em;">
				<table class="fullform">
				<tr>
					<th>Plugin + configuration</th>
					<td>
						<select name="plugins" id="plugins" class="required">
						</select>
					</td>
				</tr>
				<tr class="dynamic">
					<th></th>
					<td>
						<div id="descriptions" class="messagecontainer help" style="margin-left: 0px;">
						<%=descriptions.toString()%>
						</div>
					</td>
				</tr>
				<%
				if (messages != null && messages.size() > 0)
				{
					%>
					<tr class="big">
						<th></th>
						<td>
							<base:icon image="bullet.png" id="pluginMessages"
								tooltip="Show/hide the messages from the plugins that couldn't be used"
								>Some plugins couldn't be used</base:icon>
							<div id="pluginMessages.content" style="display: none;">
							<ul>
							<li><%=Values.getString(messages, "<li>", true)%>
							</ul>
							</div>
						</td>
					</tr>
					<%
				}
				%>
				</table>
			</div>
		</div>
		</form>
	
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnNext" title="Next" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>

