<%-- $Id: ajax.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
--%>
<%@ page pageEncoding="UTF-8" session="false" contentType="application/json"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Config"
	import="net.sf.basedb.core.File"
	import="net.sf.basedb.core.InvalidDataException"
	import="net.sf.basedb.core.Path"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.FileUtil"
	import="net.sf.basedb.util.excel.XlsxToCsvUtil"
	import="net.sf.basedb.util.error.ThrowableUtil"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="org.json.simple.JSONObject"
	import="java.io.OutputStreamWriter"
	import="java.io.Writer"
	import="java.io.Reader"
 	import="java.nio.charset.Charset"
	import="java.nio.charset.CodingErrorAction"
	import="java.nio.charset.CharsetEncoder"
	import="java.nio.charset.CharacterCodingException"
%>
<%
response.setHeader("Cache-Control", "no-cache, max-age=0");
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";
final int itemId = Values.getInt(request.getParameter("item_id"));
final String path = Values.getStringOrNull(request.getParameter("path"));
DbControl dc = null;
out.clear();
JSONObject json = new JSONObject();
json.put("status", "ok");
try
{
	if ("GetFileInfo".equals(cmd))
	{
		dc = sc.newDbControl(":Get file information");
		File f = null;
		if (itemId != 0)
		{
			f = File.getById(dc, itemId);
		}
		else
		{
			f = File.getByPath(dc, new Path(path, Path.Type.FILE), false);
		}
		json.put("id", f.getId());
		json.put("name", f.getName());
		json.put("characterSet", f.getCharacterSet());
		json.put("mimeType", f.getMimeType());
		if (Values.getBoolean(request.getParameter("checktype")))
		{
			if (XlsxToCsvUtil.seemsLikeAnExcelFile(f))
			{
				XlsxToCsvUtil util = new XlsxToCsvUtil();
				try
				{
					util.readWorkbook(f.getDownloadStream(0));
					json.put("excelMode", true);
					json.put("sheets", util.getSheetNames());
				}
				catch (Exception ex)
				{} // It was maybe not an Excel file after all
			}
		}
		dc.close();
	}
	else if ("StoreFile".equals(cmd))
	{
		String charset = null;
		try
		{
			int size = Values.getInt(request.getParameter("size"), -1);
			charset = Values.getStringOrNull(request.getParameter("charset"));
			
			dc = sc.newDbControl(":Store file");
			File f = File.getById(dc, itemId);
			Reader in = request.getReader();
			if (charset == null)
			{
				charset = Values.getString(f.getCharacterSet(), "UTF-8");
			}
			boolean charsetModified = !charset.equals(f.getCharacterSet());
			if (charsetModified) f.setCharacterSet(charset);
			Charset cs = Charset.forName(charset);
			if (!cs.canEncode())
			{
				throw new UnsupportedOperationException("Encoding is not supported by '" + charset + "'.");
			}
			CharsetEncoder encoder = Charset.forName(charset).newEncoder();
			encoder.onMalformedInput(CodingErrorAction.REPORT);
			encoder.onUnmappableCharacter(CodingErrorAction.REPORT);
			Writer toFile = new OutputStreamWriter(
					f.getUploadStream(false, f.isCompressed()), encoder);
			int copied = (int)FileUtil.copy(in, toFile);
			if (size >= 0 && copied != size)
			{
				throw new InvalidDataException("Incomplete file; expected " + size + 
					" bytes; got " + copied + ".");
			}
			toFile.flush();
			toFile.close();
			dc.commit();
			json.put("message", "File saved " + (charsetModified ? " with character set " + charset : " successfully"));
		}
		catch (CharacterCodingException ex)
		{
			throw new Exception("Save failed: The text contains characters that can't be encoded in '" + charset + "'.");
		}
		catch (Exception ex)
		{
			throw new Exception("Save failed: " + ex.getMessage(), ex);
		}
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
}
catch (Throwable t)
{
	t.printStackTrace();
	json.clear();
	json.put("status", "error");
	json.put("message", t.getMessage());
	json.put("stacktrace", ThrowableUtil.stackTraceToString(t));
}
finally
{
	json.writeJSONString(out);
	out.flush();
	if (dc != null) dc.close();
}
%>