/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	JavaScript functions for lazy-loading of information from parent/child
	items in tables.

	@author Nicklas
	@version 3.16
*/
'use strict';

var Lazy = function()
{
	var lazy = {};
	var ITEMS_IN_FIRST_BATCH = 3; // To make the page appear more responsive
	var MAX_ITEMS_IN_BATCH = 10;
	
	var lazyElements;
	var lazyNo = 0;
	var itemType;
	var subContext;
	
	lazy.initLazyItems = function()
	{
		lazyElements = document.getElementsByClassName('lazy-item');
		if (lazyElements.length > 0)
		{
			var list = document.getElementsByClassName('itemlist')[0];
			itemType = Data.get(list, 'item-type');
			subContext = Data.get(list, 'subcontext');
			lazy.loadNextBatch(ITEMS_IN_FIRST_BATCH);
		}
	}
	
	lazy.loadNextBatch = function(itemsInBatch)
	{
		var lazyItems = [];
		while (lazyNo < lazyElements.length)
		{
			var e = lazyElements[lazyNo];
			var colIndex = Data.int(e, 'index');
			if (colIndex == 0)
			{
				// Collect 'item-id' from the first column until we have 'itemsInBatch' items
				if (lazyItems.length == itemsInBatch) break;
				lazyItems[lazyItems.length] = Data.get(e, 'item-id');
			}
			Doc.removeClass(e, 'not-loaded');
			Doc.addClass(e, 'loading');
			lazyNo++;
		}
		
		// Submit request to load the items
		if (lazyItems.length > 0)
		{
			var request = Ajax.getXmlHttpRequest();
			var url = App.getRoot() + 'common/columns/ajax.jsp?ID='+App.getSessionId();
			url += '&cmd=GetLazyItemColumns';
			url += '&itemType='+encodeURIComponent(itemType);
			if (subContext) url += '&subcontext='+encodeURIComponent(subContext);
			url += '&items='+lazyItems.join(',');
			request.open("GET", url, true);
			request.send(null);
			Ajax.setReadyStateHandler(request, lazy.lazyInfoLoaded, lazy.lazyInfoLoaded);
		}
	}
	
	lazy.lazyInfoLoaded = function(request)
	{
		var response;
		try
		{
			response = JSON.parse(request.responseText);
			if (response.status != 'ok')
			{
				App.debug(request.responseText);
				return;
			}
		}
		catch (e)
		{
			App.debug(e);
			App.debug(request.responseText);
			return;
		}
		
		// Simply inject the returned HTML in the expected place
		for (var i = 0; i < response.items.length; i++)
		{
			var item = response.items[i];
			var itemId = item.id;
			for (var col = 0; col < item.data.length; col++)
			{
				var e = Doc.element('lazy-item-'+col+'-'+itemId);
				if (e)
				{
					e.innerHTML = item.data[col];
					Doc.removeClass(e, 'loading');
					Doc.removeClass(e, 'loaded');
					Doc.autoInitElements(e);
				}
			}
		}
		
		lazy.loadNextBatch(MAX_ITEMS_IN_BATCH);
	}

	return lazy;
}();

Doc.addFinalizer(Lazy.initLazyItems);

