/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var JepFilter = function()
{
	var jep = {};
	
	/**
		Initialize the page.
	*/
	jep.initPage = function()
	{
		// BioAssays
		Buttons.addClickHandler('btnAddBioAssays', jep.addBioAssays);
		Events.addEventHandler('allBioAssays', 'click', jep.allBioAssaysOnClick);
		
		var frm = document.forms['filter'];
		frm.allBioAssays.checked = frm.bioAssays.length == 0;
		jep.allBioAssaysOnClick();
		
		// Preset formulas
		Events.addEventHandler('presets', 'change', JepPlugins.presetOnChange);
		Buttons.addClickHandler('btnExpressionBuilder', JepPlugins.openExpressionBuilder);
		
		Events.addEventHandler('includeLimit', 'keypress', Events.integerOnly);
		Events.addEventHandler('excludeLimit', 'keypress', Events.integerOnly);
		
		Buttons.addClickHandler('btnNext', jep.goNext);
	}
	
	jep.allBioAssaysOnClick = function()
	{
		var frm = document.forms['filter'];
		frm.bioAssays.disabled = frm.allBioAssays.checked;
	}

	jep.addBioAssays = function()
	{
		var frm = document.forms['filter'];
		frm.allBioAssays.checked = false;
		frm.bioAssays.disabled = false;
		var ids = Link.getIdsInList(frm.bioAssays, 'BIOASSAY');
		var url = '&resetTemporary=1&exclude='+ids.join(',');
		url += '&bioassayset_id='+frm['parameter:source'].value;
		Dialogs.selectItem('BIOASSAY', 'bioAssays', 1, url);
	}
	

	jep.validateParameters = function()
	{
		var frm = document.forms['filter'];
		var exclude = Strings.trim(frm['parameter:excludeLimit'].value);
		var include = Strings.trim(frm['parameter:includeLimit'].value);
		
		if (!frm.allBioAssays.checked && frm.bioAssays.length == 0)
		{
			Forms.showNotification('btnAddBioAssays', 'You have not selected any bioassays');
			return false;
		}
		else if (Strings.trim(frm['parameter:childName'].value) == '')
		{
			Forms.showNotification(frm['parameter:childName'], 'You must enter a name for the child bioassay set');
			return false;		
		}
		else if (Strings.trim(frm['parameter:expression'].value) == '')
		{
			Forms.showNotification(frm['parameter:expression'], 'You must enter a filter expression');
			return false;
		}
		else if (exclude != '' || include != '')
		{
			exclude = parseInt(exclude);
			include = parseInt(include);
			var numBioAssays = Data.int('page-data', 'num-bioassays');
			if (include < 1 || include > numBioAssays)
			{
				Forms.showNotification(frm['parameter:includeLimit'], 'The "include" value must be between 1 and '+numBioAssays);
				frm['parameter:includeLimit'].focus();
				return false;
			}
			else if (exclude < 1 || exclude > numBioAssays)
			{
				Forms.showNotification(frm['parameter:excludeLimit'], 'The "exclude" value must be between 1 and '+numBioAssays);
				return false;
			}
			else if (exclude > include)
			{
				Forms.showNotification(frm['parameter:includeLimit'], 'The "include" value can\'t be smaller than the "exclude" value.');
				return false;
			}
		}
		
		if (Data.int('page-data', 'max-raw-mapping') != 1)
		{
			if (frm['parameter:expression'].value.search(/raw\(/) != -1)
			{
				Forms.showNotification(frm['parameter:expression'], 'Can\'t use function raw() for bioassayset with multiple mappings to raw data');
				return false;
			}
		}
		
		return true;

	}
	
	jep.goNext = function()
	{
		if (!jep.validateParameters()) return;

		var frm = document.forms['filter'];
		if (!frm.allBioAssays.checked)
		{
			var ids = Link.getIdsInList(frm.bioAssays, 'BIOASSAY');
			for (var i = 0; i < ids.length; i++)
			{
				Forms.addHidden(frm, 'parameter:bioAssays', ids[i]);
			}
		}
		frm.submit();
	}
	

	return jep;
}();

Doc.onLoad(JepFilter.initPage);

