<%-- $Id: switch.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006, 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.Application"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.News"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.util.extensions.ActionIterator"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.login.LoginFormAction"
	import="net.sf.basedb.clients.web.extensions.login.PasswordLoginFormFactory"
	import="net.sf.basedb.clients.web.extensions.login.FieldInfo"
	import="net.sf.basedb.util.Values"
	import="java.util.Map"
	import="java.util.TreeMap"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%! 
// If value is null, return "", else <prefix>+<value>+<suffix>
String valueIfNotNull(String prefix, String value, String suffix)
{
	return value == null ? "" : prefix+value+suffix;
}
%>
<%
final String login = Values.getString(request.getParameter("login"), "");
final String requestedLoginForm = Values.getString(request.getParameter("loginForm"), null);

final SessionControl sc = Base.getSessionControl(pageContext, true);
final String ID = sc.getId();
final DbControl dc = sc.newDbControl(":Switch user");
try
{
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext);
	ExtensionsInvoker<LoginFormAction> invoker = ExtensionsControl.useExtensions(jspContext, "net.sf.basedb.clients.web.login-form");

	LoginFormAction loginAction = null;
	String selectedLoginForm = null;
	Map<String, String> allForms = new TreeMap<String, String>();

	ActionIterator<LoginFormAction> it = invoker.iterate();
	while (it.hasNext())
	{
		LoginFormAction action = it.next();
		if (action != null)
		{
			String formId = action.getId();
			if (formId == null) formId = it.getExtension().getId();
			String displayName = action.getDisplayName();
			if (displayName == null) displayName = it.getExtension().getAbout().getName();
			allForms.put(formId, displayName);
			
			if (loginAction == null || formId.equals(requestedLoginForm))
			{
				loginAction = action;
				selectedLoginForm = formId;
			}
		}
	}
	if (loginAction == null)
	{
		loginAction = PasswordLoginFormFactory.INSTANCE;
		selectedLoginForm = loginAction.getId();
	}
	FieldInfo loginField = loginAction.getLoginField();
	FieldInfo passwordField = loginAction.getPasswordField();
	FieldInfo extraField = loginAction.getExtraField();
	%>
	<base:page type="popup" title="Switch user">
	<base:head styles="login.css" scripts="~login.js">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body data-login-form="<%=HTML.encodeTags(selectedLoginForm)%>" data-requested-form="<%=HTML.encodeTags(requestedLoginForm) %>">
		<h1>Switch user <base:help helpid="switchuser" /></h1>
		<form name="login" action="login.jsp" method="post">
		<input type="hidden" name="ID" value="<%=ID%>">
		<input type="hidden" name="again" value="1">
		<input type="hidden" name="redirect" value="">
		<input type="hidden" name="useAutoStartPage" value="0">
		<input type="hidden" name="deviceToken" value="">
	
		<div class="content">
			<table class="fullform input100 bottomborder" id="the-login-form" style="display: none;">
			<%
			if (allForms.size() > 1)
			{
				%>
				<tr>
					<th>Login with</th>
					<td>
					<select name="loginForm" id="loginForm" style="min-width: 10em;">
					<%
					for (Map.Entry<String, String> entry : allForms.entrySet())
					{
						String formId = entry.getKey();
						%>
						<option value="<%=formId%>" <%=formId.equals(selectedLoginForm) ? "selected" : ""%>><%=HTML.encodeTags(entry.getValue()) %>
						<%
					}
					%>
					</select>
					</td>
				</tr>
				<%
			}
			%>
			<tr <%=valueIfNotNull("class=\"", loginField.getClazz(), "\"")%> id="login-row">
				<th><%=loginField.getPrompt() %></th>
				<td><input class="text" name="login" id="login"
					type="<%=loginField.hasHiddenCharacters() ? "password" : "text"%>"
					value="<%=loginAction.rememberLastLogin() ? HTML.encodeTags(login) : ""%>" 
					<%=valueIfNotNull("style=\"", loginField.getStyle(), "\"") %>
					<%=valueIfNotNull("title=\"", loginField.getTooltip(), "\"") %>
					<%=valueIfNotNull("placeholder=\"", loginField.getPlaceHolder(), "\"") %>
					<%=loginAction.rememberLastLogin() ? "" : "autocomplete=\"off\""%>
					data-use-last-login="0"
					maxlength="100"	
					tabindex="0">
				</td>
			</tr>
			<tr <%=valueIfNotNull("class=\"", passwordField.getClazz(), "\"")%> id="password-row">
				<th><%=passwordField.getPrompt() %></th>
				<td><input class="text" name="password" id="password"
					type="<%=passwordField.hasHiddenCharacters() ? "password" : "text"%>"
					<%=valueIfNotNull("style=\"", passwordField.getStyle(), "\"") %>
					<%=valueIfNotNull("title=\"", passwordField.getTooltip(), "\"") %>
					<%=valueIfNotNull("placeholder=\"", passwordField.getPlaceHolder(), "\"") %>
					maxlength="80"
					tabindex="0">
				</td>
			</tr>
			<%
			if (extraField != null)
			{
				%>
				<tr <%=valueIfNotNull("class=\"", extraField.getClazz(), "\"")%> id="extra-row">
					<th><%=extraField.getPrompt() %></th>
					<td><input class="text" name="extraField" id="extraField"
						type="<%=extraField.hasHiddenCharacters() ? "password" : "text"%>"
						<%=valueIfNotNull("style=\"", extraField.getStyle(), "\"") %>
						<%=valueIfNotNull("title=\"", extraField.getTooltip(), "\"") %>
						<%=valueIfNotNull("placeholder=\"", extraField.getPlaceHolder(), "\"") %>
						maxlength="80"
						tabindex="0">
					</td>
				</tr>
				<%
			}
			%>
			<tr>
				<th><label for="remainOnPage">Remain on this page</label></th>
				<td><input type="checkbox" name="remainOnPage" id="remainOnPage" checked value="1"></td>
			</tr>
			<%
			if (loginAction.getHelp() != null)
			{
				%>
				<tr class="dynamic bg-filled-50 topborder">
					<td colspan="2">
					<div class="padded">
						<div class="messagecontainer help" style="font-style: italic;" id="login-help">
						<%=loginAction.getHelp() %>
						</div>
					</div>
					</td>
				</tr>
				<%
			}
			else
			{
				%>
				<tr class="dynamic">
					<th></th>
					<td></td>
				</tr>
				<%
			}
			%>
			</table>
			
		</div>
		</form>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnLogin" image="login.png" title="Login" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>

	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>

