<%-- $Id: view_session.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Session"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.UserDevice"
	import="net.sf.basedb.core.Client"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.Job"
	import="net.sf.basedb.core.ChangeHistory"
	import="net.sf.basedb.core.ChangeHistory.TransactionInfo"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.ChangeHistoryUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.util.GeoLocation"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.Set"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="p" uri="/WEB-INF/path.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.SESSION;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String tab = Values.getString(request.getParameter("tab"));
int transactId = Values.getInt(request.getParameter("transact_id"));
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":View "+itemType);
try
{
	Session s = Session.getById(dc, itemId);
	TransactionInfo tact = transactId > 0 ? ChangeHistory.getTransactionInfo(dc, transactId) : null;
	
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);

	final String mapURL = GeoLocation.getURLToMap(s.getLocationLatitude(), s.getLocationLongitude());
	String title = "View session";
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, s);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title%>" id="view-page">
	<base:head scripts="tabcontrol-2.js,~sessions.js" styles="toolbar.css,headertabcontrol.css,path.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		
		<p:path><p:pathelement
			title="Sessions" href="<%="index.jsp?ID="+ID%>" 
			/><%
			if (tact == null)
			{
				%><p:pathelement title="<%=dateTimeFormatter.format(s.getLoginTime()) +" <span class=\\\"itemsubtype\\\">(Session)</span>"%>"
				/><%
			}
			else
			{
				%><p:pathelement title="<%=dateTimeFormatter.format(tact.getTime()) +" <span class=\\\"itemsubtype\\\">(Transaction)</span>"%>"
				/><%
			}
			%></p:path>
			
		<div id="page-data" data-item-id="<%=itemId%>"></div>
		
		<t:tabcontrol 
			id="main" 
			subclass="content mastertabcontrol" 
			active="<%=tab%>">
		<t:tab id="properties" title="Properties">
			<div>
			<table class="fullform bottomborder">
			<tr>
				<th class="itemstatus">
				</th>
				<td style="padding: 0px;">
					<tbl:toolbar subclass="bottomborder bg-filled-50">
						<tbl:button 
							id="btnExport"
							image="export.png"
							data-plugin-type="EXPORT" 
							title="Export&hellip;" 
							tooltip="Export data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
						/>
						<tbl:button 
							id="btnRunPlugin"
							image="runplugin.png"  
							data-plugin-type="OTHER" 
							title="Run plugin&hellip;" 
							tooltip="Run a plugin" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
						/>
						<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
							wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
						<tbl:button
							image="help.png"
							subclass="auto-init"
							data-auto-init="help"
							data-help-id="session.view.properties"
							title="Help&hellip;"
							tooltip="Get help about this page"
						/>
					</tbl:toolbar>
				</td>
			</tr>
			<%
			if (tact != null)
			{
				Project project = null;
				boolean deniedProject = false;
				try
				{
					project = tact.getProject(dc);
				}
				catch (PermissionDeniedException ex)
				{
					deniedProject = true;
				}
				PluginDefinition plugin = null;
				boolean deniedPlugin = false;
				try
				{
					plugin = tact.getPlugin(dc);
				}
				catch (PermissionDeniedException ex)
				{
					deniedPlugin = true;
				}
				Job job = null;
				boolean deniedJob = false;
				try
				{
					job = tact.getJob(dc);
				}
				catch (PermissionDeniedException ex)
				{
					deniedJob = true;
				}
				%>
				<tr>
					<th>Transaction</th>
					<td><%=HTML.encodeTags(tact.getName()) %></td>
				</tr>
				<tr>
					<th>Time</th>
					<td><%=dateTimeFormatter.format(tact.getTime()) %></td>
				</tr>
				<tr>
					<th>Active project</th>
					<td><%=Base.getLinkedName(ID, project, deniedProject, true) %></td>
				</tr>
				<tr>
					<th>Plug-in</th>
					<td><%=Base.getLinkedName(ID, plugin, deniedPlugin, true) %></td>
				</tr>
				<tr>
					<th>Job</th>
					<td><%=Base.getLinkedName(ID, job, deniedJob, true) %></td>
				</tr>
				<%
			}
			%>
			<tr>
				<th>User</th>
				<td><base:propertyvalue item="<%=s%>" property="user" /></td>
			</tr>
			<tr>
				<th>Client application</th>
				<td><base:propertyvalue item="<%=s%>" property="client" /></td>
			</tr>
			<tr>
				<th>Device</th>
				<td><base:propertyvalue item="<%=s%>" property="device" /></td>
			</tr>
			<tr>
				<th>Login time</th>
				<td><%=dateTimeFormatter.format(s.getLoginTime())%></td>
			</tr>
			<tr>
				<th>Logout time</th>
				<td><%=dateTimeFormatter.format(s.getLogoutTime())%></td>
			</tr>
			<tr>
				<th>Authentication method</th>
				<td><%=HTML.encodeTags(s.getAuthenticationMethod())%></td>
			</tr>
			<tr>
				<th>Remote ID</th>
				<td><%=HTML.encodeTags(s.getRemoteId())%></td>
			</tr>
			<tr>
				<th>Location</th>
				<td><%=HTML.encodeTags(s.getLocation())%>
					<base:icon href="<%=mapURL%>" image="map.png" tooltip="Show map" visible="<%=mapURL != null %>" />
				</td>
			</tr>
			<tr>
				<th>Impersonated</th>
				<td><%=s.getImpersonated()%></td>
			</tr>
			<tr>
				<th>Comment</th>
				<td><%=HTML.niceFormat(s.getLoginComment())%></td>
			</tr>
			</table>
			</div>
		</t:tab>
		
		<t:tab id="history" title="Change log"
			tooltip="Displays a log with the changes made in this session"
			visible="<%=ChangeHistoryUtil.showChangeHistoryTab(sc)%>">
			<jsp:include page="../../common/history/frameset.jsp">
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="ID" value="<%=ID%>" />
				<jsp:param name="transact_id" value="<%=transactId%>" />
			</jsp:include>
		</t:tab>
		</t:tabcontrol>
		
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.commit();
}
%>
